pm4py.algo.filtering.log.end\_activities package
================================================

Submodules
----------

pm4py.algo.filtering.log.end\_activities.end\_activities\_filter module
-----------------------------------------------------------------------

.. automodule:: pm4py.algo.filtering.log.end_activities.end_activities_filter
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.filtering.log.end_activities
   :members:
   :undoc-members:
   :show-inheritance:
